Method: Rubydoop::JobDefinition#combiner
- Defined in:
- lib/rubydoop/dsl.rb
#combiner(cls = nil) ⇒ Object Also known as: combiner=
Sets the combiner class.
The equivalent of calling setCombinerClass on a Hadoop job, but instead of a Java class you pass a Ruby class and Rubydoop will wrap it in a way that works with Hadoop.
A combiner should implement reduce, just like reducers.
237 238 239 240 241 242 243 244 |
# File 'lib/rubydoop/dsl.rb', line 237 def combiner(cls=nil) if cls @job.configuration.set(Rubydoop::CombinerProxy::RUBY_CLASS_KEY, cls.name) @job.set_combiner_class(Rubydoop::CombinerProxy) @combiner = cls end @combiner end |